\name{Tukey}
\alias{Tukey}
\alias{Tukey.aov}
\alias{print.Tukey}
\alias{plot.Tukey}
\title{Perform Tukey multiple comparisons}
\description{
  Create a set of confidence intervals on the differences between the
  means of the levels of a factor with the specified family-wise
  probability of coverage.  The intervals are based on the Studentized
  range statistic.
}
\usage{
Tukey(x, which=seq(along = tabs), ordered=FALSE, conf.level=0.95, ...)
}
\arguments{
 \item{x}{A fitted model object, usually an \code{aov} class.}
 \item{which}{A list of terms in the fitted model for which the
   intervals should be calculated.  Defaults to all the terms.}
 \item{ordered}{A logical value indicating if the levels of the factor
   should be ordered according to increasing average in the sample
   before taking differences.  If \code{ordered} is true then
   the calculated differences in the means will all be positive.  The
   significant differences will be those for which the \code{lwr} end
   point is positive.
 \item{conf.level}{A numeric value between zero and one giving the
   family-wise confidence level to use.}
 \item{\dots}{Optional additional arguments.  None are used at present.}
}
\details{
  When comparing the means for the levels of a factor in an analysis of
  variance, a simple comparison using t-tests will inflate the
  probability of declaring a significant difference when it is not in
  fact present.  This because the intervals are calculated with a
  given coverage probability for each interval but the interpretation of
  the coverage is usually with respect to the entire family of
  intervals.

  John Tukey introduced intervals based on the range of the
  sample means rather than the individual differences.  The intervals
  returned by this function are based on this Studentized range
  statistics.

  Technically the intervals constructed in this way would only apply to
  balanced designs where there are the same number of observations made
  at each level of the factor.  This function incorporates an adjustment
  for sample size that produces sensible intervals for mildly unbalanced
  designs.
}
\value{
  A list with one component for each term requested in \code{which}.
  Each component is a matrix with columns \code{diff} giving the
  difference in the observed means, \code{lwr} giving the lower
  end point of the interval, and \code{upr} giving the upper end point.
}
\author{D. M. Bates}
\seealso{\code{\link{qtukey}}, \code{\link{model.tables}}}
\examples{
data(xmp10.01)
fm1 <- aov(strength ~ type, data = xmp10.01)
Tukey(fm1)
Tukey(fm1, ord = TRUE, conf = 0.9)
}
\keyword{models, regression}
